Index: main/waeup.kofa/trunk/CHANGES.txt
===================================================================
--- main/waeup.kofa/trunk/CHANGES.txt	(revision 15046)
+++ main/waeup.kofa/trunk/CHANGES.txt	(revision 15047)
@@ -4,4 +4,6 @@
 1.6.1.dev0 (unreleased)
 =======================
+
+* Rename `StudentPaymentsOverviewExporter`.
 
 * Fix `CourseTicketExporter`. Ticket level and session filter
Index: main/waeup.kofa/trunk/docs/source/userdocs/datacenter/export.rst
===================================================================
--- main/waeup.kofa/trunk/docs/source/userdocs/datacenter/export.rst	(revision 15046)
+++ main/waeup.kofa/trunk/docs/source/userdocs/datacenter/export.rst	(revision 15047)
@@ -256,6 +256,6 @@
   postprocessing by the university.
 
-DataForBursary Exporter
------------------------
+Data For Bursary Exporter
+-------------------------
 
 .. autoclass:: waeup.kofa.students.export.DataForBursaryExporter()
@@ -265,13 +265,13 @@
   .. automethod:: waeup.kofa.students.export.DataForBursaryExporter.mangle_value()
 
-Student Payments Overview Exporter
-----------------------------------
-
-.. autoclass:: waeup.kofa.students.export.StudentPaymentsOverviewExporter()
-
-  .. autoattribute:: waeup.kofa.students.export.StudentPaymentsOverviewExporter.fields
-  .. autoattribute:: waeup.kofa.students.export.StudentPaymentsOverviewExporter.title
-  .. autoattribute:: waeup.kofa.students.export.StudentPaymentsOverviewExporter.curr_year
-  .. automethod:: waeup.kofa.students.export.StudentPaymentsOverviewExporter.mangle_value()
+School Fee Payments Overview Exporter
+-------------------------------------
+
+.. autoclass:: waeup.kofa.students.export.SchoolFeePaymentsOverviewExporter()
+
+  .. autoattribute:: waeup.kofa.students.export.SchoolFeePaymentsOverviewExporter.fields
+  .. autoattribute:: waeup.kofa.students.export.SchoolFeePaymentsOverviewExporter.title
+  .. autoattribute:: waeup.kofa.students.export.SchoolFeePaymentsOverviewExporter.curr_year
+  .. automethod:: waeup.kofa.students.export.SchoolFeePaymentsOverviewExporter.mangle_value()
 
 Student Study Levels Overview Exporter
@@ -292,4 +292,13 @@
   .. autoattribute:: waeup.kofa.students.export.ComboCardDataExporter.title
   .. automethod:: waeup.kofa.students.export.ComboCardDataExporter.mangle_value()
+
+Data For Lecturer Exporter
+--------------------------
+
+.. autoclass:: waeup.kofa.students.export.DataForLecturerExporter()
+
+  .. autoattribute:: waeup.kofa.students.export.DataForLecturerExporter.fields
+  .. autoattribute:: waeup.kofa.students.export.DataForLecturerExporter.title
+  .. automethod:: waeup.kofa.students.export.DataForLecturerExporter.mangle_value()
 
 File Export
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 15046)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 15047)
@@ -3409,5 +3409,5 @@
                 exporters += [('Bursary Data', 'bursary')]
             if checkPermission('waeup.exportPaymentsOverview', self.context):
-                exporters += [('Student Payments Overview', 'paymentsoverview')]
+                exporters += [('Student Payments Overview', 'sfpaymentsoverview')]
             self.exporters = exporters
             return
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_export.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_export.py	(revision 15046)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_export.py	(revision 15047)
@@ -30,5 +30,5 @@
     StudentExporter, StudentStudyCourseExporter, StudentStudyLevelExporter,
     CourseTicketExporter, StudentPaymentExporter, BedTicketExporter,
-    StudentPaymentsOverviewExporter, StudentStudyLevelsOverviewExporter,
+    SchoolFeePaymentsOverviewExporter, StudentStudyLevelsOverviewExporter,
     ComboCardDataExporter, DataForBursaryExporter,
     StudentUnpaidPaymentExporter,
@@ -1152,10 +1152,10 @@
 
 
-class StudentPaymentsOverviewExporterTest(StudentImportExportSetup):
+class SchoolFeePaymentsOverviewExporterTest(StudentImportExportSetup):
 
     layer = FunctionalLayer
 
     def setUp(self):
-        super(StudentPaymentsOverviewExporterTest, self).setUp()
+        super(SchoolFeePaymentsOverviewExporterTest, self).setUp()
         self.setup_for_export()
         return
@@ -1163,12 +1163,12 @@
     def test_ifaces(self):
         # make sure we fullfill interface contracts
-        obj = StudentPaymentsOverviewExporter()
+        obj = SchoolFeePaymentsOverviewExporter()
         verifyObject(ICSVStudentExporter, obj)
-        verifyClass(ICSVStudentExporter, StudentPaymentsOverviewExporter)
+        verifyClass(ICSVStudentExporter, SchoolFeePaymentsOverviewExporter)
         return
 
     def test_get_as_utility(self):
         # we can get a payments exporter as utility
-        result = queryUtility(ICSVExporter, name="paymentsoverview")
+        result = queryUtility(ICSVExporter, name="sfpaymentsoverview")
         self.assertTrue(result is not None)
         return
@@ -1176,5 +1176,5 @@
     def test_export(self):
         self.setup_student(self.student)
-        exporter = StudentPaymentsOverviewExporter()
+        exporter = SchoolFeePaymentsOverviewExporter()
         exporter.export([self.student], self.outfile)
         result = open(self.outfile, 'rb').read()
@@ -1219,5 +1219,5 @@
         payment_4.p_category = u'schoolfee'
         self.student['payments']['my-4thpayment'] = payment_4
-        exporter = StudentPaymentsOverviewExporter()
+        exporter = SchoolFeePaymentsOverviewExporter()
         exporter.export_all(self.app, self.outfile)
         result = open(self.outfile, 'rb').read()
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 15046)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 15047)
@@ -1073,5 +1073,5 @@
             'studentstudylevels', 'coursetickets',
             'studentpayments', 'studentunpaidpayments',
-            'bedtickets', 'paymentsoverview',
+            'bedtickets', 'sfpaymentsoverview',
             'studylevelsoverview', 'combocard', 'bursary')
 

Index: main/waeup.kofa/trunk/src/waeup/kofa/students/export.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/export.py	(revision 15046)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/export.py	(revision 15047)
@@ -461,5 +461,5 @@
 
 class DataForBursaryExporter(StudentPaymentExporter):
-    """The DataForBursary Exporter works just like the Student Payments Exporter
+    """The DataForBursary Exporter works just like the Student Payment Exporter
     but it exports much more information about the student. It combines
     payment and student data in one table in order to spare postprocessing of 
@@ -534,11 +534,11 @@
             value, name, context=context)
 
-class StudentPaymentsOverviewExporter(StudentExporter):
-    """The Student Payments Overview Exporter first filters the set of students
+class SchoolFeePaymentsOverviewExporter(StudentExporter):
+    """The School Fee Payments Overview Exporter first filters the set of students
     by searching the students catalog. Then it exports some student base data
     together with the total school fee amount paid in each year over a
     predefined year range (current year - 9, ... , current year + 1).
     """
-    grok.name('paymentsoverview')
+    grok.name('sfpaymentsoverview')
 
     curr_year = datetime.now().year
@@ -551,5 +551,5 @@
         'entry_session', 'reg_number'
         ) + year_range_tuple
-    title = _(u'Student Payments Overview')
+    title = _(u'Student School Fee Payments Overview')
 
     def mangle_value(self, value, name, context=None):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 15046)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 15047)
@@ -3935,9 +3935,9 @@
         self.browser.getLink("Export student data").click()
         self.browser.getControl("Configure new export").click()
         # Only the paymentsoverview exporter is available for department officers
         self.assertFalse('<option value="students">' in self.browser.contents)
         self.assertTrue(
-            '<option value="paymentsoverview">' in self.browser.contents)
-        self.browser.getControl(name="exporter").value = ['paymentsoverview']
+            '<option value="sfpaymentsoverview">' in self.browser.contents)
+        self.browser.getControl(name="exporter").value = ['sfpaymentsoverview']
         self.browser.getControl(name="session").value = ['2004']
         self.browser.getControl(name="level").value = ['100']
@@ -3935,9 +3935,9 @@
         self.browser.getLink("Export student data").click()
         self.browser.getControl("Configure new export").click()
-        # Only the paymentsoverview exporter is available for department officers
+        # Only the sfpaymentsoverview exporter is available for department officers
         self.assertFalse('<option value="students">' in self.browser.contents)
         self.assertTrue(